/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2011 University of Bonn. All rights reserved.
 * Please see the LICENSE file or "Copyright notice" in builder.cpp for details.
 */

/*
 * ClearAllMoleculesAction.cpp
 *
 *  Created on: Aug 09, 2010
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "Descriptors/MoleculeDescriptor.hpp"
#include "atom.hpp"
#include "CodePatterns/Log.hpp"
#include "CodePatterns/Verbose.hpp"
#include "World.hpp"

#include <boost/foreach.hpp>
#include <iostream>
#include <string>

#include "ClearAllMoleculesAction.hpp"

using namespace MoleCuilder;

// and construct the stuff
#include "ClearAllMoleculesAction.def"
#include "Action_impl_pre.hpp"
/** =========== define the function ====================== */
Action::state_ptr SelectionClearAllMoleculesAction::performCall() {
  // obtain information
  getParametersfromValueStorage();

  std::vector<molecule *> selectedMolecules = World::getInstance().getSelectedMolecules();
  LOG(1, "Clearing molecule selection.");
  World::getInstance().clearMoleculeSelection();
  LOG(0, World::getInstance().countSelectedMolecules() << " molecules remain selected.");
  return Action::state_ptr(new SelectionClearAllMoleculesState(selectedMolecules,params));
}

Action::state_ptr SelectionClearAllMoleculesAction::performUndo(Action::state_ptr _state) {
  SelectionClearAllMoleculesState *state = assert_cast<SelectionClearAllMoleculesState*>(_state.get());

  World::getInstance().clearMoleculeSelection();
  BOOST_FOREACH(molecule *_mol, state->selectedMolecules)
    World::getInstance().selectMolecule(_mol);

  return Action::state_ptr(_state);
}

Action::state_ptr SelectionClearAllMoleculesAction::performRedo(Action::state_ptr _state){
  //SelectionClearAllMoleculesState *state = assert_cast<SelectionClearAllMoleculesState*>(_state.get());

  World::getInstance().clearMoleculeSelection();

  return Action::state_ptr(_state);
}

bool SelectionClearAllMoleculesAction::canUndo() {
  return true;
}

bool SelectionClearAllMoleculesAction::shouldUndo() {
  return true;
}
/** =========== end of function ====================== */
